@@ -17,16 +17,21 @@ $conf_dir = '';
 $model_to_test = "MiniPlain";
 
 {
-    package MyReader;
+    package Config::Model::Backend::MyReader;
     use Path::Tiny;
     use Test::More;
+    use Mouse ;
+
+    extends 'Config::Model::Backend::Any';
 
     sub my_log {
         note("plainfile backend test: @_");
     }
 
     sub read {
+        my $self = shift;
         my %args = @_;
+
         my $dir = $args{root}.$args{config_dir};
         foreach my $file (path($dir)->children()) {
             my_log("dummy read file $file");
@@ -37,6 +42,7 @@ $model_to_test = "MiniPlain";
     }
 
     sub write {
+        my $self = shift;
         mylog("dummy write called");
         return 1;
     }
@@ -65,7 +71,7 @@ $model->create_config_class(
         auto_delete => '1',
         backend => 'PlainFile',
         config_dir => 'debian',
-        file_mode => 'a+x',
+        file_mode => '0755',
         file => '&index(-).&element(-).&element'
     }]
 );
@@ -86,9 +92,8 @@ $model->create_config_class(
     ],
 
     read_config => [{
-        backend    => 'custom',
+        backend    => 'MyReader',
         config_dir => 'debian',
-        class      => 'MyReader',
         auto_delete => '1',
     }],
 );
